@@ -16,6 +16,20 @@ class Console:
             help="Log level to be used",
             dest="loglevel",
         )
+        parser.add_argument(
+            "--dumpobj",
+            required=False,
+            help="Serialize objets found, mainly for test purpose",
+            dest="dumpobj",
+            action="store_true",
+        )
+        parser.add_argument(
+            "--no-ui",
+            required=False,
+            help="Discard UI,  mainly for test purpose",
+            dest="no_ui",
+            action="store_true",
+        )
         parser.add_argument(
             "path", nargs="+", help="Path of a root directory to be analysed"
         )
